"""
Main module for gitads-pypi package
"""

def hello_world():
    """
    Returns a hello world message
    """
    return "Hello World from gitads-pypi!"

def main():
    """
    Main entry point for the console script
    """
    print(hello_world())
    return 0

if __name__ == "__main__":
    main()